configfile

package
v0.25.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 26, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const ConfigFileName = "metadata.json"
const DefaultDeletionsRetentionDays = 7

DefaultDeletionsRetentionDays is the default retention period for deletion records.

Variables

This section is empty.

Functions

func ConfigPath

func ConfigPath(beadsDir string) string

Types

type Config

type Config struct {
	Database      string `json:"database"`
	JSONLExport   string `json:"jsonl_export,omitempty"`
	LastBdVersion string `json:"last_bd_version,omitempty"`

	// Deletions configuration
	DeletionsRetentionDays int `json:"deletions_retention_days,omitempty"` // 0 means use default (7 days)
}

func DefaultConfig

func DefaultConfig() *Config

func Load

func Load(beadsDir string) (*Config, error)

func (*Config) DatabasePath

func (c *Config) DatabasePath(beadsDir string) string

func (*Config) GetDeletionsRetentionDays added in v0.25.0

func (c *Config) GetDeletionsRetentionDays() int

GetDeletionsRetentionDays returns the configured retention days, or the default if not set.

func (*Config) JSONLPath

func (c *Config) JSONLPath(beadsDir string) string

func (*Config) Save

func (c *Config) Save(beadsDir string) error

Jump to