debug

package
v0.41.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 30, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Enabled

func Enabled() bool

func IsQuiet added in v0.24.3

func IsQuiet() bool

IsQuiet returns true if quiet mode is enabled

func Logf

func Logf(format string, args ...interface{})

func PrintNormal added in v0.24.3

func PrintNormal(format string, args ...interface{})

PrintNormal prints output unless quiet mode is enabled Use this for normal informational output that should be suppressed in quiet mode

func Printf

func Printf(format string, args ...interface{})

func PrintlnNormal added in v0.24.3

func PrintlnNormal(args ...interface{})

PrintlnNormal prints a line unless quiet mode is enabled

func SetQuiet added in v0.24.3

func SetQuiet(quiet bool)

SetQuiet enables quiet mode (suppress non-essential output)

func SetVerbose added in v0.24.3

func SetVerbose(verbose bool)

SetVerbose enables verbose/debug output

Types

This section is empty.

Jump to