Documentation
¶
Index ¶
Constants ¶
const ConfigFileName = "metadata.json"
const DefaultDeletionsRetentionDays = 7
DefaultDeletionsRetentionDays is the default retention period for deletion records.
Variables ¶
This section is empty.
Functions ¶
func ConfigPath ¶
Types ¶
type Config ¶
type Config struct {
Database string `json:"database"`
JSONLExport string `json:"jsonl_export,omitempty"`
LastBdVersion string `json:"last_bd_version,omitempty"`
// Deletions configuration
DeletionsRetentionDays int `json:"deletions_retention_days,omitempty"` // 0 means use default (7 days)
}
func DefaultConfig ¶
func DefaultConfig() *Config
func (*Config) DatabasePath ¶
func (*Config) GetDeletionsRetentionDays ¶ added in v0.25.0
GetDeletionsRetentionDays returns the configured retention days, or the default if not set.
Click to show internal directories.
Click to hide internal directories.