Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PrintNormal ¶ added in v0.24.3
func PrintNormal(format string, args ...interface{})
PrintNormal prints output unless quiet mode is enabled Use this for normal informational output that should be suppressed in quiet mode
func PrintlnNormal ¶ added in v0.24.3
func PrintlnNormal(args ...interface{})
PrintlnNormal prints a line unless quiet mode is enabled
func SetQuiet ¶ added in v0.24.3
func SetQuiet(quiet bool)
SetQuiet enables quiet mode (suppress non-essential output)
func SetVerbose ¶ added in v0.24.3
func SetVerbose(verbose bool)
SetVerbose enables verbose/debug output
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.